[Libreoffice-commits] core.git: sw/source

Miklos Vajna vmiklos at collabora.co.uk
Sun Mar 8 12:16:30 PDT 2015


 sw/source/core/frmedt/feshview.cxx   |    4 
 sw/source/uibase/app/docst.cxx       |    6 -
 sw/source/uibase/app/swmodule.cxx    |    2 
 sw/source/uibase/dochdl/swdtflvr.cxx |   18 +--
 sw/source/uibase/docvw/edtdd.cxx     |   30 ++---
 sw/source/uibase/docvw/edtwin.cxx    |  186 +++++++++++++++++------------------
 sw/source/uibase/ribbar/conform.cxx  |    4 
 sw/source/uibase/ribbar/drawbase.cxx |   16 +--
 sw/source/uibase/shells/textfld.cxx  |    6 -
 sw/source/uibase/uiview/view.cxx     |   16 +--
 sw/source/uibase/uiview/view1.cxx    |    4 
 sw/source/uibase/wrtsh/wrtsh3.cxx    |    8 -
 12 files changed, 150 insertions(+), 150 deletions(-)

New commits:
commit 930e9fa318855b03755d2632020d770ca7ccbfd7
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Sun Mar 8 18:22:25 2015 +0100

    sw: prefix global variables in edtwin
    
    Change-Id: Iee32ede1cc474a361fb3b1bf47f1c52b4ff2c4b7
    Reviewed-on: https://gerrit.libreoffice.org/14799
    Reviewed-by: Miklos Vajna <vmiklos at collabora.co.uk>
    Tested-by: Jenkins <ci at libreoffice.org>

diff --git a/sw/source/core/frmedt/feshview.cxx b/sw/source/core/frmedt/feshview.cxx
index 501d52e..6b3cdb4 100644
--- a/sw/source/core/frmedt/feshview.cxx
+++ b/sw/source/core/frmedt/feshview.cxx
@@ -115,13 +115,13 @@ static void lcl_GrabCursor( SwFEShell* pSh, SwFlyFrm* pOldSelFly)
     {
         // now call set macro if applicable
         pSh->GetFlyMacroLnk().Call( (void*)pFlyFmt );
-extern bool bNoInterrupt;       // in swapp.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
         // if a dialog was started inside a macro, then
         // MouseButtonUp arrives at macro and not to us. Therefore
         // flag is always set here and will never be switched to
         // respective Shell !!!!!!!
 
-        bNoInterrupt = false;
+        g_bNoInterrupt = false;
     }
     else if( !pFlyFmt || RES_DRAWFRMFMT == pFlyFmt->Which() )
     {
diff --git a/sw/source/uibase/app/swmodule.cxx b/sw/source/uibase/app/swmodule.cxx
index 4a8038c..a9af46e 100644
--- a/sw/source/uibase/app/swmodule.cxx
+++ b/sw/source/uibase/app/swmodule.cxx
@@ -128,7 +128,7 @@
 #include <app.hrc>
 #include <svx/xmlsecctrl.hxx>
 ResMgr *pSwResMgr = 0;
-bool     bNoInterrupt     = false;
+bool     g_bNoInterrupt     = false;
 
 #include <sfx2/app.hxx>
 
diff --git a/sw/source/uibase/dochdl/swdtflvr.cxx b/sw/source/uibase/dochdl/swdtflvr.cxx
index fa2c553..68dc961 100644
--- a/sw/source/uibase/dochdl/swdtflvr.cxx
+++ b/sw/source/uibase/dochdl/swdtflvr.cxx
@@ -130,9 +130,9 @@
 #include <boost/scoped_array.hpp>
 #include <boost/scoped_ptr.hpp>
 
-extern bool bFrmDrag;
-extern bool bDDINetAttr;
-extern bool bExecuteDrag;
+extern bool g_bFrmDrag;
+extern bool g_bDDINetAttr;
+extern bool g_bExecuteDrag;
 
 #define OLESIZE 11905 - 2 * lMinBorder, 6 * MM50
 
@@ -457,7 +457,7 @@ bool SwTransferable::GetData( const DataFlavor& rFlavor, const OUString& rDestDo
 
             Point aPos( SwEditWin::GetDDStartPosX(), SwEditWin::GetDDStartPosY());
 
-            bool bSelect = bExecuteDrag &&
+            bool bSelect = g_bExecuteDrag &&
                             pWrtShell->GetView().GetDocShell() &&
                             !pWrtShell->GetView().GetDocShell()->IsReadOnly();
             if( pWrtShell->GetContentAtPos( aPos, aCntntAtPos, bSelect ) )
@@ -2037,7 +2037,7 @@ void SwTransferable::SetSelInShell( SwWrtShell& rSh, bool bSelectFrm,
             {
                 rSh.HideCrsr();
                 rSh.EnterSelFrmMode( pPt );
-                bFrmDrag = true;
+                g_bFrmDrag = true;
             }
         }
     }
@@ -2048,7 +2048,7 @@ void SwTransferable::SetSelInShell( SwWrtShell& rSh, bool bSelectFrm,
             rSh.UnSelectFrm();
             rSh.LeaveSelFrmMode();
             rSh.GetView().GetEditWin().StopInsFrm();
-            bFrmDrag = false;
+            g_bFrmDrag = false;
         }
         else if( rSh.GetView().GetDrawFuncPtr() )
             rSh.GetView().GetEditWin().StopInsFrm();
@@ -3312,7 +3312,7 @@ bool SwTransferable::PrivateDrop( SwWrtShell& rSh, const Point& rDragPt,
             {
                 rSh.HideCrsr();
                 rSh.EnterSelFrmMode( &rDragPt );
-                bFrmDrag = true;
+                g_bFrmDrag = true;
             }
 
             const int nSelection = rSh.GetSelectionType();
@@ -3334,7 +3334,7 @@ bool SwTransferable::PrivateDrop( SwWrtShell& rSh, const Point& rDragPt,
                 rSh.LeaveSelFrmMode();
                 rSh.UnSelectFrm();
                 rSh.ShowCrsr();
-                bFrmDrag = false;
+                g_bFrmDrag = false;
             }
         }
     }
@@ -3441,7 +3441,7 @@ bool SwTransferable::PrivateDrop( SwWrtShell& rSh, const Point& rDragPt,
         // is there an URL attribute at the insert point? Then replace that,
         // so simply put up a selection?
         rSh.DelINetAttrWithText();
-        bDDINetAttr = true;
+        g_bDDINetAttr = true;
     }
 
     if ( rSrcSh.IsSelFrmMode() )
diff --git a/sw/source/uibase/docvw/edtdd.cxx b/sw/source/uibase/docvw/edtdd.cxx
index 1928973..32f0a0f 100644
--- a/sw/source/uibase/docvw/edtdd.cxx
+++ b/sw/source/uibase/docvw/edtdd.cxx
@@ -43,24 +43,24 @@ using namespace ::com::sun::star;
 
 // no include "dbgoutsw.hxx" here!!!!!!
 
-extern bool bNoInterrupt;
-extern bool bFrmDrag;
-extern bool bDDTimerStarted;
+extern bool g_bNoInterrupt;
+extern bool g_bFrmDrag;
+extern bool g_bDDTimerStarted;
 
-bool bExecuteDrag = false;
+bool g_bExecuteDrag = false;
 
 void SwEditWin::StartDDTimer()
 {
     m_aTimer.SetTimeoutHdl(LINK(this, SwEditWin, DDHandler));
     m_aTimer.SetTimeout(480);
     m_aTimer.Start();
-    bDDTimerStarted = true;
+    g_bDDTimerStarted = true;
 }
 
 void SwEditWin::StopDDTimer(SwWrtShell *pSh, const Point &rPt)
 {
     m_aTimer.Stop();
-    bDDTimerStarted = false;
+    g_bDDTimerStarted = false;
     if(!pSh->IsSelFrmMode())
         pSh->SetCursor(&rPt, false);
     m_aTimer.SetTimeoutHdl(LINK(this,SwEditWin, TimerHandler));
@@ -87,7 +87,7 @@ void SwEditWin::StartDrag( sal_Int8 /*nAction*/, const Point& rPosPixel )
         if ( !rSh.IsInSelect() && rSh.ChgCurrPam( aDocPos, true, true))
             //We are not selecting and aren't at a selection
             bStart = true;
-        else if ( !bFrmDrag && rSh.IsSelFrmMode() &&
+        else if ( !g_bFrmDrag && rSh.IsSelFrmMode() &&
                     rSh.IsInsideSelectedObj( aDocPos ) )
         {
             //We are not dragging internally and are not at an
@@ -95,7 +95,7 @@ void SwEditWin::StartDrag( sal_Int8 /*nAction*/, const Point& rPosPixel )
 
             bStart = true;
         }
-        else if( !bFrmDrag && m_rView.GetDocShell()->IsReadOnly() &&
+        else if( !g_bFrmDrag && m_rView.GetDocShell()->IsReadOnly() &&
                 OBJCNT_NONE != rSh.GetObjCntType( aDocPos, pObj ))
         {
             rSh.LockPaint();
@@ -116,8 +116,8 @@ void SwEditWin::StartDrag( sal_Int8 /*nAction*/, const Point& rPosPixel )
         {
             m_bMBPressed = false;
             ReleaseMouse();
-            bFrmDrag = false;
-            bExecuteDrag = true;
+            g_bFrmDrag = false;
+            g_bExecuteDrag = true;
             SwEditWin::m_nDDStartPosY = aDocPos.Y();
             SwEditWin::m_nDDStartPosX = aDocPos.X();
             m_aMovePos = aDocPos;
@@ -133,7 +133,7 @@ void SwEditWin::StartDrag( sal_Int8 /*nAction*/, const Point& rPosPixel )
 
 void SwEditWin::StartExecuteDrag()
 {
-    if( !bExecuteDrag || m_bIsInDrag )
+    if( !g_bExecuteDrag || m_bIsInDrag )
         return;
 
     m_bIsInDrag = true;
@@ -157,7 +157,7 @@ void SwEditWin::DropCleanup()
     SwWrtShell &rSh =  m_rView.GetWrtShell();
 
     // reset statuses
-    bNoInterrupt = false;
+    g_bNoInterrupt = false;
     if ( m_bOldIdleSet )
     {
         const_cast<SwViewOption*>(rSh.GetViewOptions())->SetIdle( m_bOldIdle );
@@ -477,16 +477,16 @@ sal_Int8 SwEditWin::AcceptDrop( const AcceptDropEvent& rEvt )
 
 IMPL_LINK_NOARG(SwEditWin, DDHandler)
 {
-    bDDTimerStarted = false;
+    g_bDDTimerStarted = false;
     m_aTimer.Stop();
     m_aTimer.SetTimeout(240);
     m_bMBPressed = false;
     ReleaseMouse();
-    bFrmDrag = false;
+    g_bFrmDrag = false;
 
     if ( m_rView.GetViewFrame() )
     {
-        bExecuteDrag = true;
+        g_bExecuteDrag = true;
         StartExecuteDrag();
     }
     return 0;
diff --git a/sw/source/uibase/docvw/edtwin.cxx b/sw/source/uibase/docvw/edtwin.cxx
index 8648d03..939a56e 100644
--- a/sw/source/uibase/docvw/edtwin.cxx
+++ b/sw/source/uibase/docvw/edtwin.cxx
@@ -159,23 +159,23 @@ using namespace ::com::sun::star;
 /**
  * Globals
  */
-static bool bInputLanguageSwitched = false;
-extern bool bNoInterrupt;       // in mainwn.cxx
+static bool g_bInputLanguageSwitched = false;
+extern bool g_bNoInterrupt;       // in mainwn.cxx
 
 // Usually in MouseButtonUp a selection is revoked when the selection is
 // not currently being pulled open. Unfortunately in MouseButtonDown there
 // is being selected at double/triple click. That selection is completely
 // finished in the Handler and thus can't be distinguished in the Up.
-// To resolve this bHoldSelection is set in Down at evaluated in Up.
-static bool bHoldSelection      = false;
+// To resolve this g_bHoldSelection is set in Down at evaluated in Up.
+static bool g_bHoldSelection      = false;
 
-bool bFrmDrag                   = false;
-bool bValidCrsrPos              = false;
-bool bModePushed                = false;
-bool bDDTimerStarted            = false;
-bool bFlushCharBuffer           = false;
-bool bDDINetAttr                = false;
-SdrHdlKind eSdrMoveHdl          = HDL_USER;
+bool g_bFrmDrag                   = false;
+bool g_bValidCrsrPos              = false;
+bool g_bModePushed                = false;
+bool g_bDDTimerStarted            = false;
+bool g_bFlushCharBuffer           = false;
+bool g_bDDINetAttr                = false;
+SdrHdlKind g_eSdrMoveHdl          = HDL_USER;
 
 QuickHelpData* SwEditWin::m_pQuickHlpData = 0;
 
@@ -192,7 +192,7 @@ long    SwEditWin::m_nDDStartPosX = 0;
 Color   SwEditWin::m_aTextBackColor(COL_YELLOW);
 Color   SwEditWin::m_aTextColor(COL_RED);
 
-extern bool     bExecuteDrag;
+extern bool     g_bExecuteDrag;
 
 static SfxShell* lcl_GetShellFromDispatcher( SwView& rView, TypeId nType );
 
@@ -608,7 +608,7 @@ IMPL_LINK_NOARG(SwEditWin, TimerHandler)
             m_rView.Scroll( Rectangle(aModPt,Size(1,1)), nMaxScroll, nMaxScroll);
             bDone = true;
         }
-        else if ( bFrmDrag )
+        else if ( g_bFrmDrag )
         {
             rSh.Drag(&aModPt, false);
             bDone = true;
@@ -616,7 +616,7 @@ IMPL_LINK_NOARG(SwEditWin, TimerHandler)
         if ( !bDone )
             aModPt = rSh.GetCntntPos( aModPt,aModPt.Y() > rSh.VisArea().Bottom() );
     }
-    if ( !bDone && !(bFrmDrag || m_bInsDraw) )
+    if ( !bDone && !(g_bFrmDrag || m_bInsDraw) )
     {
         if ( m_pRowColumnSelectionStart )
         {
@@ -779,7 +779,7 @@ static sal_uInt16 lcl_isNonDefaultLanguage(LanguageType eBufferLanguage, SwView&
                     // current language attribute equal to language reported from system
                     bLang = false;
                 }
-                else if ( !bInputLanguageSwitched && RES_CHRATR_LANGUAGE == nWhich )
+                else if ( !g_bInputLanguageSwitched && RES_CHRATR_LANGUAGE == nWhich )
                 {
                     // special case: switching between two "LATIN" languages
                     // In case the current keyboard setting might be suitable
@@ -964,7 +964,7 @@ void SwEditWin::FlushInBuffer()
         rSh.Insert( m_aInBuffer );
         m_eBufferLanguage = LANGUAGE_DONTKNOW;
         m_aInBuffer.clear();
-        bFlushCharBuffer = false;
+        g_bFlushCharBuffer = false;
     }
 }
 
@@ -2410,9 +2410,9 @@ KEYINPUT_CHECKTABLE_INSDEL:
                     comphelper::string::padToLength(aBuf,
                         m_aInBuffer.getLength() + aKeyEvent.GetRepeat() + 1, aCh);
                     m_aInBuffer = aBuf.makeStringAndClear();
-                    bFlushCharBuffer = Application::AnyInput( VclInputFlags::KEYBOARD );
-                    bFlushBuffer = !bFlushCharBuffer;
-                    if( bFlushCharBuffer )
+                    g_bFlushCharBuffer = Application::AnyInput( VclInputFlags::KEYBOARD );
+                    bFlushBuffer = !g_bFlushCharBuffer;
+                    if( g_bFlushCharBuffer )
                         m_aKeyInputFlushTimer.Start();
                 }
                 eKeyState = KS_End;
@@ -2653,9 +2653,9 @@ KEYINPUT_CHECKTABLE_INSDEL:
     {
         // bFlushCharBuffer was not resetted here
         // why not?
-        bool bSave = bFlushCharBuffer;
+        bool bSave = g_bFlushCharBuffer;
         FlushInBuffer();
-        bFlushCharBuffer = bSave;
+        g_bFlushCharBuffer = bSave;
 
         // maybe show Tip-Help
         OUString sWord;
@@ -2685,7 +2685,7 @@ void SwEditWin::RstMBDownFlags()
     // So reset the statuses here and release the mouse
     // for the dialog.
     m_bMBPressed = false;
-    bNoInterrupt = false;
+    g_bNoInterrupt = false;
     EnterArea();
     ReleaseMouse();
 }
@@ -2786,8 +2786,8 @@ void touch_lo_selection_end_move_impl(const void *documentHandle,
 void SwEditWin::MoveCursor( SwWrtShell &rSh, const Point& rDocPos,
                             const bool bOnlyText, bool bLockView )
 {
-    const bool bTmpNoInterrupt = bNoInterrupt;
-    bNoInterrupt = false;
+    const bool bTmpNoInterrupt = g_bNoInterrupt;
+    g_bNoInterrupt = false;
 
     int nTmpSetCrsr = 0;
 
@@ -2801,7 +2801,7 @@ void SwEditWin::MoveCursor( SwWrtShell &rSh, const Point& rDocPos,
         // the query to the content form doesn't work!!!
         SwMvContext aMvContext( &rSh );
         nTmpSetCrsr = rSh.SetCursor(&rDocPos, bOnlyText);
-        bValidCrsrPos = !(CRSR_POSCHG & nTmpSetCrsr);
+        g_bValidCrsrPos = !(CRSR_POSCHG & nTmpSetCrsr);
     }
 
     // notify the edit window that from now on we do not use the input language
@@ -2811,7 +2811,7 @@ void SwEditWin::MoveCursor( SwWrtShell &rSh, const Point& rDocPos,
     if( bLockView )
         rSh.LockView( false );
 
-    bNoInterrupt = bTmpNoInterrupt;
+    g_bNoInterrupt = bTmpNoInterrupt;
 }
 
 void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
@@ -3078,7 +3078,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
     {
         bool bOnlyText = false;
         m_bMBPressed = true;
-        bNoInterrupt = true;
+        g_bNoInterrupt = true;
         m_nKS_NUMDOWN_Count = 0;
 
         CaptureMouse();
@@ -3110,7 +3110,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                 }
                 if ( !bTiledRendering && EnterDrawMode( rMEvt, aDocPos ) )
                 {
-                    bNoInterrupt = false;
+                    g_bNoInterrupt = false;
                     return;
                 }
                 else  if ( m_rView.GetDrawFuncPtr() && m_bInsFrm )
@@ -3141,9 +3141,9 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                     SwEditWin::m_nDDStartPosY = aDocPos.Y();
                                     SwEditWin::m_nDDStartPosX = aDocPos.X();
                                 }
-                                bFrmDrag = true;
+                                g_bFrmDrag = true;
                             }
-                            bNoInterrupt = false;
+                            g_bNoInterrupt = false;
                             return;
                         }
                     }
@@ -3235,7 +3235,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                     }
 
                                     rSh.EnterSelFrmMode( &aDocPos );
-                                    bFrmDrag = true;
+                                    g_bFrmDrag = true;
                                     UpdatePointer( aDocPos, rMEvt.GetModifier() );
                                 }
                                 return;
@@ -3287,7 +3287,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                             {
                                 // move cursor here so that it is not drawn in the
                                 // frame first; ShowCrsr() happens in LeaveSelFrmMode()
-                                bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
+                                g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
                                 rSh.LeaveSelFrmMode();
                                 m_rView.AttrChangedNotify( &rSh );
                                 bCallBase = false;
@@ -3298,7 +3298,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                 rSh.EnterSelFrmMode( &aDocPos );
                                 rSh.SelFlyGrabCrsr();
                                 rSh.MakeSelVisible();
-                                bFrmDrag = true;
+                                g_bFrmDrag = true;
                                 if( rSh.IsFrmSelected() &&
                                     m_rView.GetDrawFuncPtr() )
                                 {
@@ -3320,7 +3320,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         break;
                     case 2:
                     {
-                        bFrmDrag = false;
+                        g_bFrmDrag = false;
                         if ( !bHandledFlyClick && !bIsDocReadOnly && rSh.IsInsideSelectedObj(aDocPos) &&
                              0 == rSh.IsSelObjProtected( FLYPROTECT_CONTENT|FLYPROTECT_PARENT ) )
                         {
@@ -3363,7 +3363,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
 
                         // if the cursor position was corrected or if a Fly
                         // was selected in ReadOnlyMode, no word selection.
-                        if ( !bValidCrsrPos || rSh.IsFrmSelected() )
+                        if ( !g_bValidCrsrPos || rSh.IsFrmSelected() )
                             return;
 
                         SwField *pFld;
@@ -3415,13 +3415,13 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         }
                         else
                             rSh.SelWrd( &aDocPos );
-                        bHoldSelection = true;
+                        g_bHoldSelection = true;
                         return;
                     }
                     case 3:
                     case 4:
                     {
-                        bFrmDrag = false;
+                        g_bFrmDrag = false;
                         // in extended mode double and triple
                         // click has no effect.
                         if ( rSh.IsExtMode() )
@@ -3429,7 +3429,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
 
                         // if the cursor position was corrected or if a Fly
                         // was selected in ReadOnlyMode, no word selection.
-                        if ( !bValidCrsrPos || rSh.IsFrmSelected() )
+                        if ( !g_bValidCrsrPos || rSh.IsFrmSelected() )
                             return;
 
                         // select line, AdditionalMode if applicable
@@ -3448,7 +3448,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         if ( bMod )
                             rSh.LeaveAddMode();
 
-                        bHoldSelection = true;
+                        g_bHoldSelection = true;
                         return;
                     }
 
@@ -3478,7 +3478,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                     rSh.EnterSelFrmMode( &aDocPos );
                                     SwEditWin::m_nDDStartPosY = aDocPos.Y();
                                     SwEditWin::m_nDDStartPosX = aDocPos.X();
-                                    bFrmDrag = true;
+                                    g_bFrmDrag = true;
                                     return;
                                 }
                             }
@@ -3486,8 +3486,8 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         else if( rSh.IsSelFrmMode() &&
                                  rSh.GetDrawView()->PickHandle( aDocPos ))
                         {
-                            bFrmDrag = true;
-                            bNoInterrupt = false;
+                            g_bFrmDrag = true;
+                            g_bNoInterrupt = false;
                             return;
                         }
                     }
@@ -3507,7 +3507,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                     rSh.EnterSelFrmMode( &aDocPos );
                                     SwEditWin::m_nDDStartPosY = aDocPos.Y();
                                     SwEditWin::m_nDDStartPosX = aDocPos.X();
-                                    bFrmDrag = true;
+                                    g_bFrmDrag = true;
                                     return;
                                 }
                             }
@@ -3515,8 +3515,8 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         else if( rSh.IsSelFrmMode() &&
                                  rSh.GetDrawView()->PickHandle( aDocPos ))
                         {
-                            bFrmDrag = true;
-                            bNoInterrupt = false;
+                            g_bFrmDrag = true;
+                            g_bNoInterrupt = false;
                             return;
                         }
                         else
@@ -3524,7 +3524,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                             if ( !rSh.IsAddMode() && !rSh.IsExtMode() && !rSh.IsBlockMode() )
                             {
                                 rSh.PushMode();
-                                bModePushed = true;
+                                g_bModePushed = true;
 
                                 bool bUnLockView = !rSh.IsViewLocked();
                                 rSh.LockView( true );
@@ -3541,7 +3541,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                         if ( !rSh.IsAddMode() && !rSh.IsExtMode() && !rSh.IsBlockMode() )
                         {
                             rSh.PushMode();
-                            bModePushed = true;
+                            g_bModePushed = true;
                             bool bUnLockView = !rSh.IsViewLocked();
                             rSh.LockView( true );
                             rSh.EnterBlockMode();
@@ -3566,7 +3566,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                 {
                                     rSh.LeaveSelFrmMode();
                                     m_rView.AttrChangedNotify(&rSh);
-                                    bFrmDrag = false;
+                                    g_bFrmDrag = false;
                                 }
                             }
                             else
@@ -3575,7 +3575,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                     rSh.EnterSelFrmMode( &aDocPos );
                                     SwEditWin::m_nDDStartPosY = aDocPos.Y();
                                     SwEditWin::m_nDDStartPosX = aDocPos.X();
-                                    bFrmDrag = true;
+                                    g_bFrmDrag = true;
                                     return;
                                 }
                             }
@@ -3588,7 +3588,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                 rSh.EnterSelFrmMode( &aDocPos );
                                 SwEditWin::m_nDDStartPosY = aDocPos.Y();
                                 SwEditWin::m_nDDStartPosX = aDocPos.X();
-                                bFrmDrag = true;
+                                g_bFrmDrag = true;
                                 return;
                             }
                             if ( rSh.IsSelFrmMode() )
@@ -3596,7 +3596,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
                                 rSh.UnSelectFrm();
                                 rSh.LeaveSelFrmMode();
                                 m_rView.AttrChangedNotify(&rSh);
-                                bFrmDrag = false;
+                                g_bFrmDrag = false;
                             }
                             if ( !rSh.IsExtMode() )
                             {
@@ -3732,7 +3732,7 @@ void SwEditWin::MouseButtonDown(const MouseEvent& _rMEvt)
         SwContentAtPos aFieldAtPos(SwContentAtPos::SW_FIELD);
 
         // Are we clicking on a field?
-        if (bValidCrsrPos
+        if (g_bValidCrsrPos
             && rSh.GetContentAtPos(aDocPos, aFieldAtPos)
             && aFieldAtPos.pFndTxtAttr != NULL
             && aFieldAtPos.pFndTxtAttr->Which() == RES_TXTATR_INPUTFIELD
@@ -3818,7 +3818,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
 
     // position is necessary for OS/2 because obviously after a MB-Down
     // a MB-Move is called immediately.
-    if( bDDTimerStarted )
+    if( g_bDDTimerStarted )
     {
         Point aDD( SwEditWin::m_nDDStartPosX, SwEditWin::m_nDDStartPosY );
         aDD = LogicToPixel( aDD );
@@ -3998,7 +3998,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
             if ( !m_bMBPressed )
                 break;
         case MOUSE_LEFT + KEY_MOD1:
-            if ( bFrmDrag && rSh.IsSelFrmMode() )
+            if ( g_bFrmDrag && rSh.IsSelFrmMode() )
             {
                 if( !m_bMBPressed )
                     break;
@@ -4014,13 +4014,13 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
                         const Point aSttPt( PixelToLogic( m_aStartPos ) );
 
                         // can we start?
-                        if( HDL_USER == eSdrMoveHdl )
+                        if( HDL_USER == g_eSdrMoveHdl )
                         {
                             SdrHdl* pHdl = pSdrView->PickHandle( aSttPt );
-                            eSdrMoveHdl = pHdl ? pHdl->GetKind() : HDL_MOVE;
+                            g_eSdrMoveHdl = pHdl ? pHdl->GetKind() : HDL_MOVE;
                         }
 
-                        sal_uInt16 nEvent = HDL_MOVE == eSdrMoveHdl
+                        sal_uInt16 nEvent = HDL_MOVE == g_eSdrMoveHdl
                                             ? SW_EVENT_FRM_MOVE
                                             : SW_EVENT_FRM_RESIZE;
 
@@ -4040,7 +4040,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
                             if( SW_EVENT_FRM_RESIZE == nEvent )
                             {
                                 xVar = new SbxVariable;
-                                xVar->PutUShort( static_cast< sal_uInt16 >(eSdrMoveHdl) );
+                                xVar->PutUShort( static_cast< sal_uInt16 >(g_eSdrMoveHdl) );
                                 xArgs->Put( &xVar, ++nPos );
                             }
 
@@ -4069,7 +4069,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
                         break;
 
                     bool bIsSelectionGfx = rSh.GetSelectionType() & nsSelectionType::SEL_GRF;
-                    bool bisResize = eSdrMoveHdl != HDL_MOVE;
+                    bool bisResize = g_eSdrMoveHdl != HDL_MOVE;
 
                     if (pSdrView)
                     {
@@ -4107,7 +4107,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
                     EnterArea();
                 return;
             }
-            if ( !rSh.IsSelFrmMode() && !bDDINetAttr &&
+            if ( !rSh.IsSelFrmMode() && !g_bDDINetAttr &&
                 (IsMinMove( m_aStartPos,aPixPt ) || m_bIsInMove) &&
                 (rSh.IsInSelect() || !rSh.ChgCurrPam( aDocPt )) )
             {
@@ -4133,12 +4133,12 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
                     {
                         rSh.Drag( &aDocPt, false );
 
-                        bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPt, false));
+                        g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPt, false));
                         EnterArea();
                     }
                 }
             }
-            bDDINetAttr = false;
+            g_bDDINetAttr = false;
             break;
         case 0:
         {
@@ -4244,7 +4244,7 @@ void SwEditWin::MouseMove(const MouseEvent& _rMEvt)
             if( rSh.IsBlockMode() && !rMEvt.IsSynthetic() )
             {
                 rSh.Drag( &aDocPt, false );
-                bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPt, false));
+                g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPt, false));
                 EnterArea();
             }
         break;
@@ -4270,8 +4270,8 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
     if( m_pRowColumnSelectionStart )
         DELETEZ( m_pRowColumnSelectionStart );
 
-    SdrHdlKind eOldSdrMoveHdl = eSdrMoveHdl;
-    eSdrMoveHdl = HDL_USER;     // for MoveEvents - reset again
+    SdrHdlKind eOldSdrMoveHdl = g_eSdrMoveHdl;
+    g_eSdrMoveHdl = HDL_USER;     // for MoveEvents - reset again
 
     // preventively reset
     m_rView.SetTabColFromDoc( false );
@@ -4301,16 +4301,16 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
 
     Point aDocPt( PixelToLogic( rMEvt.GetPosPixel() ) );
 
-    if ( bDDTimerStarted )
+    if ( g_bDDTimerStarted )
     {
         StopDDTimer( &rSh, aDocPt );
         m_bMBPressed = false;
         if ( rSh.IsSelFrmMode() )
         {
             rSh.EndDrag( &aDocPt, false );
-            bFrmDrag = false;
+            g_bFrmDrag = false;
         }
-        bNoInterrupt = false;
+        g_bNoInterrupt = false;
         const Point aDocPos( PixelToLogic( rMEvt.GetPosPixel() ) );
         if ((PixelToLogic(m_aStartPos).Y() == (aDocPos.Y())) && (PixelToLogic(m_aStartPos).X() == (aDocPos.X())))//To make sure it was not moved
         {
@@ -4383,7 +4383,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
             else
             {
                 const Point aDocPos( PixelToLogic( m_aStartPos ) );
-                bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
+                g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
                 rSh.Edit();
             }
 
@@ -4392,7 +4392,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
         else if (rMEvt.GetButtons() == MOUSE_RIGHT && rSh.IsDrawCreate())
             m_rView.GetDrawFuncPtr()->BreakCreate();   // abort drawing
 
-        bNoInterrupt = false;
+        g_bNoInterrupt = false;
         ReleaseMouse();
         return;
     }
@@ -4417,7 +4417,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
         case MOUSE_LEFT + KEY_MOD1:
         case MOUSE_LEFT + KEY_MOD2:
         case MOUSE_LEFT + KEY_SHIFT + KEY_MOD1:
-            if ( bFrmDrag && rSh.IsSelFrmMode() )
+            if ( g_bFrmDrag && rSh.IsSelFrmMode() )
             {
                 if ( rMEvt.IsMod1() ) // copy and don't move.
                 {
@@ -4498,7 +4498,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
                     }
                     rSh.EndDrag( &aDocPt, false );
                 }
-                bFrmDrag = false;
+                g_bFrmDrag = false;
                 bCallBase = false;
                 break;
             }
@@ -4509,15 +4509,15 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
             {
 
                 rSh.EndDrag( &aDocPt, false );
-                bFrmDrag = false;
+                g_bFrmDrag = false;
                 bCallBase = false;
                 break;
             }
 
-            if( bHoldSelection )
+            if( g_bHoldSelection )
             {
                 // the EndDrag should be called in any case
-                bHoldSelection = false;
+                g_bHoldSelection = false;
                 rSh.EndDrag( &aDocPt, false );
             }
             else
@@ -4525,15 +4525,15 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
                 SwContentAtPos aFieldAtPos ( SwContentAtPos::SW_FIELD );
                 if ( !rSh.IsInSelect() && rSh.ChgCurrPam( aDocPt ) && !rSh.GetContentAtPos( aDocPt, aFieldAtPos ) )
                 {
-                    const bool bTmpNoInterrupt = bNoInterrupt;
-                    bNoInterrupt = false;
+                    const bool bTmpNoInterrupt = g_bNoInterrupt;
+                    g_bNoInterrupt = false;
                     {   // create only temporary move context because otherwise
                         // the query to the content form doesn't work!!!
                         SwMvContext aMvContext( &rSh );
                         const Point aDocPos( PixelToLogic( m_aStartPos ) );
-                        bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
+                        g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
                     }
-                    bNoInterrupt = bTmpNoInterrupt;
+                    g_bNoInterrupt = bTmpNoInterrupt;
 
                 }
                 else
@@ -4600,11 +4600,11 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
                                         // the query to the content form doesn't work!!!
                                         SwMvContext aMvContext( &rSh );
                                         const Point aDocPos( PixelToLogic( m_aStartPos ) );
-                                        bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
+                                        g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
                                     }
                                     else
                                     {
-                                        bValidCrsrPos = true;
+                                        g_bValidCrsrPos = true;
                                     }
                                 }
                                 else
@@ -4613,7 +4613,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
                                     // a bit of a mystery what this is good for?
                                     // in this case we assume it's valid since we
                                     // just selected a field
-                                    bValidCrsrPos = true;
+                                    g_bValidCrsrPos = true;
                                 }
                                 if (bAddMode)
                                 {
@@ -4713,10 +4713,10 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
             }
 
             // reset pushed mode in Down again if applicable
-            if ( bPopMode && bModePushed )
+            if ( bPopMode && g_bModePushed )
             {
                 rSh.PopMode();
-                bModePushed = false;
+                g_bModePushed = false;
                 bCallBase = false;
             }
             break;
@@ -4881,7 +4881,7 @@ void SwEditWin::MouseButtonUp(const MouseEvent& rMEvt)
     // Make this call just to be sure. Selecting has finished surely by now.
     // Otherwise the timeout's timer could give problems.
     EnterArea();
-    bNoInterrupt = false;
+    g_bNoInterrupt = false;
 
     if (bCallBase)
         Window::MouseButtonUp(rMEvt);
@@ -5029,7 +5029,7 @@ SwEditWin::~SwEditWin()
     delete m_pRowColumnSelectionStart;
     if( m_pQuickHlpData->m_bIsDisplayed && m_rView.GetWrtShellPtr() )
         m_pQuickHlpData->Stop( m_rView.GetWrtShell() );
-    bExecuteDrag = false;
+    g_bExecuteDrag = false;
     delete m_pApplyTempl;
     m_rView.SetDrawFuncPtr(NULL);
 
@@ -5086,7 +5086,7 @@ bool SwEditWin::EnterDrawMode(const MouseEvent& rMEvt, const Point& aDocPos)
         {
             SwEditWin::m_nDDStartPosY = aDocPos.Y();
             SwEditWin::m_nDDStartPosX = aDocPos.X();
-            bFrmDrag = true;
+            g_bFrmDrag = true;
         }
         if( bUnLockView )
             rSh.LockView( false );
@@ -5183,10 +5183,10 @@ void SwEditWin::Command( const CommandEvent& rCEvt )
                 SET_CURR_SHELL( &rSh );
                 if (!m_pApplyTempl)
                 {
-                    if (bNoInterrupt)
+                    if (g_bNoInterrupt)
                     {
                         ReleaseMouse();
-                        bNoInterrupt = false;
+                        g_bNoInterrupt = false;
                         m_bMBPressed = false;
                     }
                     if ( rCEvt.IsMouseEvent() )
@@ -5409,7 +5409,7 @@ void SwEditWin::Command( const CommandEvent& rCEvt )
         break;
         case COMMAND_INPUTLANGUAGECHANGE :
             // i#42732 - update state of fontname if input language changes
-            bInputLanguageSwitched = true;
+            g_bInputLanguageSwitched = true;
             SetUseInputLanguage( true );
         break;
         case COMMAND_SELECTIONCHANGE:
@@ -5651,7 +5651,7 @@ bool SwEditWin::SelectMenuPosition(SwWrtShell& rSh, const Point& rMousePos )
                     }
 
                     rSh.EnterSelFrmMode( &aDocPos );
-                    bFrmDrag = true;
+                    g_bFrmDrag = true;
                     UpdatePointer( aDocPos, 0 );
                     return bRet;
                 }
@@ -5686,7 +5686,7 @@ bool SwEditWin::SelectMenuPosition(SwWrtShell& rSh, const Point& rMousePos )
         {
             // move cursor here so that it is not drawn in the
             // frame at first; ShowCrsr() happens in LeaveSelFrmMode()
-            bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
+            g_bValidCrsrPos = !(CRSR_POSCHG & rSh.SetCursor(&aDocPos, false));
             rSh.LeaveSelFrmMode();
             m_rView.LeaveDrawCreate();
             m_rView.AttrChangedNotify( &rSh );
@@ -5698,7 +5698,7 @@ bool SwEditWin::SelectMenuPosition(SwWrtShell& rSh, const Point& rMousePos )
             rSh.EnterSelFrmMode( &aDocPos );
             rSh.SelFlyGrabCrsr();
             rSh.MakeSelVisible();
-            bFrmDrag = true;
+            g_bFrmDrag = true;
             if( rSh.IsFrmSelected() &&
                 m_rView.GetDrawFuncPtr() )
             {
diff --git a/sw/source/uibase/ribbar/conform.cxx b/sw/source/uibase/ribbar/conform.cxx
index 1c0441d..95612c2 100644
--- a/sw/source/uibase/ribbar/conform.cxx
+++ b/sw/source/uibase/ribbar/conform.cxx
@@ -27,7 +27,7 @@
 #include "drawbase.hxx"
 #include "conform.hxx"
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 ConstFormControl::ConstFormControl(SwWrtShell* pWrtShell, SwEditWin* pEditWin, SwView* pSwView) :
     SwDrawBase(pWrtShell, pEditWin, pSwView)
@@ -62,7 +62,7 @@ bool ConstFormControl::MouseButtonDown(const MouseEvent& rMEvt)
     if (rMEvt.IsLeft() && !m_pWin->IsDrawAction() &&
         (eHit == SDRHIT_UNMARKEDOBJECT || eHit == SDRHIT_NONE || m_pSh->IsDrawCreate()))
     {
-        bNoInterrupt = true;
+        g_bNoInterrupt = true;
         m_pWin->CaptureMouse();
 
         m_pWin->SetPointer(Pointer(POINTER_DRAW_RECT));
diff --git a/sw/source/uibase/ribbar/drawbase.cxx b/sw/source/uibase/ribbar/drawbase.cxx
index cda8945..3c122ca 100644
--- a/sw/source/uibase/ribbar/drawbase.cxx
+++ b/sw/source/uibase/ribbar/drawbase.cxx
@@ -39,7 +39,7 @@
 
 using namespace ::com::sun::star;
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 SwDrawBase::SwDrawBase(SwWrtShell* pSwWrtShell, SwEditWin* pWindow, SwView* pSwView) :
     m_pView(pSwView),
@@ -88,7 +88,7 @@ bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
     {
         if (IsCreateObj() && (eHit == SDRHIT_UNMARKEDOBJECT || eHit == SDRHIT_NONE || m_pSh->IsDrawCreate()))
         {
-            bNoInterrupt = true;
+            g_bNoInterrupt = true;
             m_pWin->CaptureMouse();
 
             m_aStartPos = m_pWin->PixelToLogic(rMEvt.GetPosPixel());
@@ -110,14 +110,14 @@ bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
             if (eHit == SDRHIT_HANDLE && aVEvt.pHdl->GetKind() == HDL_BWGT)
             {
                 // Drag handle
-                bNoInterrupt = true;
+                g_bNoInterrupt = true;
                 bReturn = pSdrView->BegDragObj(m_aStartPos, (OutputDevice*) NULL, aVEvt.pHdl);
                 m_pWin->SetDrawAction(true);
             }
             else if (eHit == SDRHIT_MARKEDOBJECT && nEditMode == SID_BEZIER_INSERT)
             {
                 // Insert gluepoint
-                bNoInterrupt = true;
+                g_bNoInterrupt = true;
                 bReturn = pSdrView->BegInsObjPoint(m_aStartPos, rMEvt.IsMod1());
                 m_pWin->SetDrawAction(true);
             }
@@ -162,7 +162,7 @@ bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
 
                     if (pHdl)
                     {
-                        bNoInterrupt = true;
+                        g_bNoInterrupt = true;
                         pSdrView->MarkPoint(*pHdl);
                     }
                 }
@@ -175,12 +175,12 @@ bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
                     if (pSdrView->HasMarkablePoints())
                         pSdrView->UnmarkAllPoints();
 
-                    bNoInterrupt = false;
+                    g_bNoInterrupt = false;
                     // Use drag in edtwin
                     return false;
                 }
 
-                bNoInterrupt = true;
+                g_bNoInterrupt = true;
 
                 if (m_pSh->IsObjSelected())
                 {
@@ -444,7 +444,7 @@ void SwDrawBase::Deactivate()
     m_pWin->SetDrawAction(false);
 
     m_pWin->ReleaseMouse();
-    bNoInterrupt = false;
+    g_bNoInterrupt = false;
 
     if(m_pWin->GetApplyTemplate())
         m_pWin->SetApplyTemplate(SwApplyTemplate());
diff --git a/sw/source/uibase/shells/textfld.cxx b/sw/source/uibase/shells/textfld.cxx
index b6aac7c..8493175 100644
--- a/sw/source/uibase/shells/textfld.cxx
+++ b/sw/source/uibase/shells/textfld.cxx
@@ -74,7 +74,7 @@
 
 using namespace nsSwDocInfoSubType;
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 static OUString lcl_BuildTitleWithRedline( const SwRangeRedline *pRedline )
 {
@@ -513,7 +513,7 @@ void SwTextShell::ExecField(SfxRequest &rReq)
                     }
 
                     SwViewShell::SetCareWin(pDlg->GetWindow());
-                    bNoInterrupt = true;
+                    g_bNoInterrupt = true;
 
                     if ( pDlg->Execute() == RET_OK )
                     {
@@ -526,7 +526,7 @@ void SwTextShell::ExecField(SfxRequest &rReq)
 
                     pDlg.reset();
                     SwViewShell::SetCareWin(NULL);
-                    bNoInterrupt = false;
+                    g_bNoInterrupt = false;
                     rSh.ClearMark();
                     GetView().AttrChangedNotify(GetShellPtr());
                 }
diff --git a/sw/source/uibase/uiview/view.cxx b/sw/source/uibase/uiview/view.cxx
index 4ab8fa0..650b9f3 100644
--- a/sw/source/uibase/uiview/view.cxx
+++ b/sw/source/uibase/uiview/view.cxx
@@ -117,7 +117,7 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::scanner;
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 #define SWVIEWFLAGS ( SFX_VIEW_CAN_PRINT|               \
                       SFX_VIEW_HAS_PRINTOPTIONS)
@@ -476,16 +476,16 @@ IMPL_LINK_NOARG(SwView, AttrChangedNotify)
         GetEditWin().SetChainMode( false );
 
     //Opt: Not if PaintLocked. During unlock a notify will be once more triggered.
-    if( !m_pWrtShell->IsPaintLocked() && !bNoInterrupt &&
+    if( !m_pWrtShell->IsPaintLocked() && !g_bNoInterrupt &&
         GetDocShell()->IsReadOnly() )
         _CheckReadonlyState();
 
-    if( !m_pWrtShell->IsPaintLocked() && !bNoInterrupt )
+    if( !m_pWrtShell->IsPaintLocked() && !g_bNoInterrupt )
         _CheckReadonlySelection();
 
     if( !m_bAttrChgNotified )
     {
-        if ( m_pWrtShell->BasicActionPend() || bNoInterrupt ||
+        if ( m_pWrtShell->BasicActionPend() || g_bNoInterrupt ||
              GetDispatcher().IsLocked() ||               //do not confuse the SFX
              GetViewFrame()->GetBindings().IsInUpdate() )//do not confuse the SFX
         {
@@ -520,7 +520,7 @@ IMPL_LINK_NOARG(SwView, AttrChangedNotify)
 
 IMPL_LINK_NOARG(SwView, TimeoutHdl)
 {
-    if( m_pWrtShell->BasicActionPend() || bNoInterrupt )
+    if( m_pWrtShell->BasicActionPend() || g_bNoInterrupt )
     {
         m_aTimer.Start();
         return 0;
@@ -872,8 +872,8 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
 
     // In CTOR no shell changes may take place, which must be temporarily stored
     // with the timer. Otherwise, the SFX removes them from the stack!
-    bool bOld = bNoInterrupt;
-    bNoInterrupt = true;
+    bool bOld = g_bNoInterrupt;
+    g_bNoInterrupt = true;
 
     m_pHRuler->SetActive( true );
     m_pVRuler->SetActive( true );
@@ -980,7 +980,7 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         m_pWrtShell->ResetModified();
     }
 
-    bNoInterrupt = bOld;
+    g_bNoInterrupt = bOld;
 
     // If a new GlobalDoc will be created, the navigator will also be generated.
     if( pDocSh->IsA(SwGlobalDocShell::StaticType()) &&
diff --git a/sw/source/uibase/uiview/view1.cxx b/sw/source/uibase/uiview/view1.cxx
index cc54ec9..9695e36 100644
--- a/sw/source/uibase/uiview/view1.cxx
+++ b/sw/source/uibase/uiview/view1.cxx
@@ -116,9 +116,9 @@ void SwView::Activate(bool bMDIActivate)
 
 void SwView::Deactivate(bool bMDIActivate)
 {
-    extern bool bFlushCharBuffer ;
+    extern bool g_bFlushCharBuffer ;
         // Are Characters still in the input buffer?
-    if( bFlushCharBuffer )
+    if( g_bFlushCharBuffer )
         GetEditWin().FlushInBuffer();
 
     if( bMDIActivate )
diff --git a/sw/source/uibase/wrtsh/wrtsh3.cxx b/sw/source/uibase/wrtsh/wrtsh3.cxx
index a5a1bb4..cb265a2 100644
--- a/sw/source/uibase/wrtsh/wrtsh3.cxx
+++ b/sw/source/uibase/wrtsh/wrtsh3.cxx
@@ -38,7 +38,7 @@
 
 using namespace ::com::sun::star;
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 bool SwWrtShell::MoveBookMark( BookMarkMove eFuncId, const ::sw::mark::IMark* const pMark)
 {
@@ -121,10 +121,10 @@ void SwWrtShell::DrawSelChanged( )
 
     GetView().GetViewFrame()->GetBindings().Invalidate(aInval);
 
-    bool bOldVal = bNoInterrupt;
-    bNoInterrupt = true;    // Trick to run AttrChangedNotify by timer.
+    bool bOldVal = g_bNoInterrupt;
+    g_bNoInterrupt = true;    // Trick to run AttrChangedNotify by timer.
     GetView().AttrChangedNotify(this);
-    bNoInterrupt = bOldVal;
+    g_bNoInterrupt = bOldVal;
 }
 
 bool SwWrtShell::GotoMark( const OUString& rName )


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/uibase/app/docst.cxx b/sw/source/uibase/app/docst.cxx
index 8eafb05..07e380a 100644
--- a/sw/source/uibase/app/docst.cxx
+++ b/sw/source/uibase/app/docst.cxx
@@ -85,7 +85,7 @@
 
 #include <paratr.hxx>
 
-extern bool bNoInterrupt;       // in mainwn.cxx
+extern bool g_bNoInterrupt;       // in swmodule.cxx
 
 using namespace ::com::sun::star;
 
@@ -1264,8 +1264,8 @@ void SwDocShell::_LoadStyles( SfxObjectShell& rSource, bool bPreserveCurrentDocu
             // rhbz#818557, fdo#58893: EndAllAction will call SelectShell(),
             // which pushes a bunch of SfxShells that are not cleared
             // (for unknown reasons) when closing the document, causing crash;
-            // setting bNoInterrupt appears to avoid the problem.
-            ::comphelper::FlagRestorationGuard g(bNoInterrupt, true);
+            // setting g_bNoInterrupt appears to avoid the problem.
+            ::comphelper::FlagRestorationGuard g(g_bNoInterrupt, true);
             mpWrtShell->StartAllAction();
             mpDoc->ReplaceStyles( *static_cast<SwDocShell&>(rSource).mpDoc );
             mpWrtShell->EndAllAction();